import request from "@/utils/request"

// 刷新令牌
export const refreshToken = (refreshToken) => {
  return request({
    url: '/menduner/system/auth/refresh-token',
    method: "POST",
    params: {
      refreshToken
    },
    custom: {
      showLoading: false,
      showError: false
    }
  })
}

// 发送手机验证码
export const sendSmsCode = (data) => {
  return request({
    url: '/menduner/system/auth/send-sms-code',
    method: "POST",
    data,
    custom: {
      loadingMsg: '发送中',
      showSuccess: true,
      successMsg: '发送成功'
    }
  })
}

// 短信登录
export const smsLogin = (data) => {
  return request({
    url: '/menduner/system/auth/sms-login',
    method: 'POST',
    data,
    custom: {
      showLoading: false
    }
  })
}

// 密码登录
export const passwordLogin = (data) => {
  return request({
    url: '/menduner/system/auth/login',
    method: 'POST',
    data,
    custom: {
      showLoading: false
    }
  })
}

// 退出登录
export const logout = () => {
  return request({
    url: '/menduner/system/auth/logout',
    method: 'POST',
    custom: {
      showLoading: false,
      auth: true
    }
  })
}

// 字典
export const getDictData = (params) => {
  return request({
    url: '/system/dict-data/type',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取行业列表
export const getIndustryListData = (params) => {
  return request({
    url: '/menduner/system/industry/list',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取技能列表
export const getSkillList = () => {
  return request({
    url: '/menduner/system/skill/list',
    method: 'GET',
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取行业树形
export const getIndustryTreeData = (params) => {
  return request({
    url: '/menduner/system/industry/get/tree',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取地区列表
export const getAreaListData = (params) => {
  return request({
    url: '/menduner/system/area/list',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取地区获取地区map
export const getAreaMapData = (params) => {
  return request({
    url: '/menduner/system/area/map',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获得职位类型
export const getPositionTreeData = (params) => {
  return request({
    url: '/menduner/system/position/get/tree',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取职位列表
export const getPositionData = (params) => {
  return request({
    url: '/menduner/system/position/list',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取区域树形
export const getAreaTreeData = () => {
  return request({
    url: '/menduner/system/area/get/tree',
    method: 'GET',
    custom: {
      showLoading: false,
      auth: false
    }
  })
}